@@ -10,22 +10,24 @@ test_that("Errors and messages", {
   v_sf <- sf::st_as_sf(v)
 
   # Errors
-  expect_error(ggplot(r) +
-    geom_spatraster_contour_filled())
   expect_error(
+    ggplot(r) +
+      geom_spatraster_contour_filled()
+  )
+  expect_snapshot(
     ggplot() +
       geom_spatraster_contour_filled(data = v),
-    regexp = "only works with SpatRaster"
+    error = TRUE
   )
-  expect_error(
+  expect_snapshot(
     ggplot() +
       geom_spatraster_contour_filled(data = 1:3),
-    regexp = "only works with SpatRaster"
+    error = TRUE
   )
-  expect_error(
+  expect_snapshot(
     ggplot() +
       geom_spatraster_contour_filled(data = r, aes(z = noexist)),
-    regexp = "Layer noexist not found"
+    error = TRUE
   )
   s <- ggplot() +
     geom_spatraster_contour_filled(data = r) +
@@ -38,6 +40,7 @@ test_that("Errors and messages", {
       data = r,
       breaks = c(0, 1)
     )
+  expect_snapshot(end <- ggplot_build(ff), error = TRUE)
 })
 
 
@@ -66,13 +69,20 @@ test_that("Test plot", {
   vdiffr::expect_doppelganger("02-projected", p + coord_sf(crs = 3857))
 
   # Faceted
+  # If not throw message
+  aa <- ggplot() +
+    geom_spatraster_contour_filled(data = r)
+  expect_snapshot(end <- ggplot_build(aa))
   p_facet <- ggplot() +
     geom_spatraster_contour_filled(data = r) +
     facet_wrap(~lyr)
 
   vdiffr::expect_doppelganger("03-faceted with aes", p_facet)
-  vdiffr::expect_doppelganger("04-faceted with aes and crs", p_facet +
-    coord_sf(crs = 3857))
+  vdiffr::expect_doppelganger(
+    "04-faceted with aes and crs",
+    p_facet +
+      coord_sf(crs = 3857)
+  )
 
 
   # Aes for a single layer
@@ -110,8 +120,11 @@ test_that("Test plot", {
     scale_fill_terrain_d()
 
   vdiffr::expect_doppelganger("07-align binwd", binw)
-  vdiffr::expect_doppelganger("08-align binwd trans", binw +
-    coord_sf(crs = 3857))
+  vdiffr::expect_doppelganger(
+    "08-align binwd trans",
+    binw +
+      coord_sf(crs = 3857)
+  )
 
   binn <- ggplot() +
     geom_sf(data = v_sf, fill = "grey80") +
@@ -123,8 +136,11 @@ test_that("Test plot", {
     scale_fill_terrain_d()
 
   vdiffr::expect_doppelganger("09-align bins", binn)
-  vdiffr::expect_doppelganger("10-align bins trans", binn +
-    coord_sf(crs = 3857))
+  vdiffr::expect_doppelganger(
+    "10-align bins trans",
+    binn +
+      coord_sf(crs = 3857)
+  )
 
   bin_breaks <- ggplot() +
     geom_sf(data = v_sf, fill = "grey80") +
@@ -139,8 +155,11 @@ test_that("Test plot", {
     scale_fill_terrain_d(direction = -1)
 
   vdiffr::expect_doppelganger("11-align breaks", bin_breaks)
-  vdiffr::expect_doppelganger("12-align breaks trans", bin_breaks +
-    coord_sf(crs = 3857))
+  vdiffr::expect_doppelganger(
+    "12-align breaks trans",
+    bin_breaks +
+      coord_sf(crs = 3857)
+  )
 })
 
 
